import { createStorefrontApiClient } from '@shopify/storefront-api-client';
import { REACT_APP_ACCESS_TOKEN, REACT_APP_SHOP_NAME } from '../utils/httpCommon';

const client = createStorefrontApiClient({
  storeDomain: `https://${REACT_APP_SHOP_NAME}/api/2024-10/graphql.json`,
  apiVersion: '2024-10',
  publicAccessToken: REACT_APP_ACCESS_TOKEN,
});

// Create a cart
const createCart = async () => {
  const query = `
    mutation CreateCart {
      cartCreate {
        cart {
          id
          createdAt
          updatedAt
        }
        userErrors {
          field
          message
        }
      }
    }
  `;
  const { data } = await client.request(query);
  return data.cartCreate.cart;
};

// Add a line item to the cart
const addItemToCart = async (cartId, lines) => {
  const query = `
    mutation AddItemToCart($cartId: ID!, $lines: [CartLineInput!]!) {
      cartLinesAdd(cartId: $cartId, lines: $lines) {
        cart {
          id
          lines(first: 10) {
            edges {
              node {
                id
                quantity
                merchandise {
                  ... on ProductVariant {
                    id
                    title
                  }
                }
              }
            }
          }
        }
        userErrors {
          field
          message
        }
      }
    }
  `;
  const variables = { cartId, lines };
  const { data } = await client.request(query, variables);
  return data.cartLinesAdd.cart;
};

// Get cart details
const getCart = async (cartId) => {
  const query = `
    query GetCart($cartId: ID!) {
      cart(id: $cartId) {
        id
        createdAt
        updatedAt
        lines(first: 10) {
          edges {
            node {
              id
              quantity
              merchandise {
                ... on ProductVariant {
                  id
                  title
                }
              }
            }
          }
        }
        cost {
          subtotalAmount {
            amount
            currencyCode
          }
          totalAmount {
            amount
            currencyCode
          }
          totalTaxAmount {
            amount
            currencyCode
          }
        }
      }
    }
  `;

   
  const variables = { cartId };
  const { data } = await client.request(query, variables);
  debugger
  return data.cart;
};

// Update a line item's quantity
const updateItemQuantity = async (cartId, lineId, quantity) => {
  const query = `
    mutation UpdateItemQuantity($cartId: ID!, $lines: [CartLineUpdateInput!]!) {
      cartLinesUpdate(cartId: $cartId, lines: $lines) {
        cart {
          id
          lines(first: 10) {
            edges {
              node {
                id
                quantity
                merchandise {
                  ... on ProductVariant {
                    id
                  }
                }
              }
            }
          }
        }
        userErrors {
          field
          message
        }
      }
    }
  `;
  const variables = {
    cartId,
    lines: [{ id: lineId, quantity }],
  };
  const { data } = await client.request(query, variables);
  return data.cartLinesUpdate.cart;
};

// Generate checkout URL
const getCheckoutUrl = async (cartId) => {
  const query = `
    query CheckoutURL($cartId: ID!) {
      cart(id: $cartId) {
        checkoutUrl
      }
    }
  `;
  const variables = { cartId };
  const { data } = await client.request(query, variables);
  return data.cart.checkoutUrl;
};

// Export services
const CartService = {
  createCart,
  addItemToCart,
  getCart,
  updateItemQuantity,
  getCheckoutUrl,
};

export default CartService;
